@@ -33,6 +33,7 @@ typedef enum {
 
 	/* task things */
 	MEMO = 1,
+	NOTES,
 	TASK_TIME,
 	BILLSTATUS,
 	BILLABLE,
@@ -86,12 +87,12 @@ do_show_journal (GttGhtml *ghtml, GttProject*prj)
 {
 	GList *node;
 	char *p;
-	char prn[2000];
+	char prn[62000];  /* XXX stack smashing overflow */
 
 	p = prn;
 	p += sprintf (p, "<table border=1><tr><th colspan=4>%s\n"
 		"<tr><th>&nbsp;<th>%s<th>%s<th>%s",
-		_("Memo"), _("Start"), _("Stop"), _("Elapsed"));
+		_("Diary Entry"), _("Start"), _("Stop"), _("Elapsed"));
 
 	(ghtml->write_stream) (ghtml, prn, p-prn, ghtml->user_data);
 
@@ -106,7 +107,7 @@ do_show_journal (GttGhtml *ghtml, GttProject*prj)
 		p = prn;
 		p = stpcpy (p, "<tr><td colspan=4>"
 			"<a href=\"gtt:task:");
-		p += sprintf (p, "%p\">", tsk);
+		p += sprintf (p, "0x%x\">", tsk);
 
 		pp = gtt_task_get_memo(tsk);
 		if (!pp || !pp[0]) pp = _("(empty)");
@@ -130,7 +131,7 @@ do_show_journal (GttGhtml *ghtml, GttProject*prj)
 				"<tr><td>&nbsp;&nbsp;&nbsp;"
 				"<td align=right>&nbsp;&nbsp;"
 				"<a href=\"gtt:interval:");
-			p += sprintf (p, "%p\">", ivl);
+			p += sprintf (p, "0x%x\">", ivl);
 
 			/* print hour only or date too? */
 			if (0 != prev_stop) {
@@ -148,7 +149,7 @@ do_show_journal (GttGhtml *ghtml, GttProject*prj)
 				"</a>&nbsp;&nbsp;"
 				"<td>&nbsp;&nbsp;"
 				"<a href=\"gtt:interval:");
-			p += sprintf (p, "%p\">", ivl);
+			p += sprintf (p, "0x%x\">", ivl);
 			if (prt_date) {
 				p = print_date_time (p, 70, stop);
 			} else {
@@ -196,7 +197,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int show_links, int invoice)
 	int i;
 	GList *node;
 	char *p;
-	char buff[2000];
+	char buff[62000];   /* XXX stack smashing bug */
 
 	p = buff;
 	p = stpcpy (p, "<table border=1>");
@@ -216,9 +217,13 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int show_links, int invoice)
 				mcols = ghtml->ninvl_cols - ghtml->ntask_cols;
 				if (0 >= mcols) mcols = 1; 
 				p += sprintf (p, "<th colspan=%d>", mcols);
-				TASK_COL_TITLE (_("Memo"));
+				TASK_COL_TITLE (_("Diary Entry"));
 				break;
 			}
+			case NOTES:
+				p = stpcpy (p, "<th>");
+				TASK_COL_TITLE (_("Notes"));
+				break;
 			case TASK_TIME:
 				p = stpcpy (p, "<th>");
 				TASK_COL_TITLE (_("Task Time"));
@@ -358,7 +363,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int show_links, int invoice)
 					if (show_links) 
 					{
 						p = stpcpy (p, "<a href=\"gtt:task:");
-						p += sprintf (p, "%p\">", tsk);
+						p += sprintf (p, "0x%x\">", tsk);
 					}
 					pp = gtt_task_get_memo(tsk);
 					if (!pp || !pp[0]) pp = _("(empty)");
@@ -367,6 +372,13 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int show_links, int invoice)
 					break;
 				}
 
+				case NOTES:
+					p = stpcpy (p, "<td align=left>");
+					pp = gtt_task_get_notes(tsk);
+					if (!pp || !pp[0]) pp = _("(empty)");
+					p = stpcpy (p, pp);
+					break;
+					
 				case TASK_TIME:
 					p = stpcpy (p, "<td align=right>");
 					p = print_hours_elapsed (p, 40, task_secs, TRUE);
@@ -483,7 +495,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int show_links, int invoice)
 		p = stpcpy (p, "<td align=right>&nbsp;&nbsp;");
 		if (show_links)
 		{
-			p += sprintf (p, "<a href=\"gtt:interval:%p\">", ivl);
+			p += sprintf (p, "<a href=\"gtt:interval:0x%x\">", ivl);
 		}
 		if (prt_start_date) {
 			p = print_date_time (p, 100, start);
@@ -499,7 +511,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int show_links, int invoice)
 		p = stpcpy (p, "<td align=right>&nbsp;&nbsp;");
 		if (show_links)
 		{
-			p += sprintf (p, "<a href=\"gtt:interval:%p\">", ivl);
+			p += sprintf (p, "<a href=\"gtt:interval:0x%x\">", ivl);
 		}
 		if (prt_stop_date) {
 			p = print_date_time (p, 100, stop);
@@ -651,6 +663,11 @@ decode_column (GttGhtml *ghtml, const char * tok)
 		TASK_COL(MEMO);
 	}
 	else
+	if (0 == strncmp (tok, "$notes", 6))
+	{
+		TASK_COL(NOTES);
+	}
+	else
 	if (0 == strncmp (tok, "$task_time", 10))
 	{
 		TASK_COL(TASK_TIME);
@@ -755,6 +772,16 @@ do_show_scm (GttGhtml *ghtml, SCM node)
 	int len;
 	char * str = NULL;
 
+	/* Need to test for numbers first, since later tests 
+	 * may core-dump guile-1.3.4 */
+	if (SCM_NUMBERP(node))
+	{
+		char buf[132];
+		double x = scm_num2dbl (node, "do_show_scm");
+		sprintf (buf, "%g ", x);
+		(ghtml->write_stream) (ghtml, buf, strlen(buf), ghtml->user_data);
+	}
+	else
 	/* either a 'symbol or a "quoted string" */
 	if (SCM_SYMBOLP(node) || SCM_STRINGP (node))
 	{
@@ -764,14 +791,6 @@ do_show_scm (GttGhtml *ghtml, SCM node)
 		free (str);
 	}
 	else
-	if (SCM_NUMBERP(node))
-	{
-		char buf[132];
-		double x = SCM_NUM2DBL (node);
-		sprintf (buf, "%g ", x);
-		(ghtml->write_stream) (ghtml, buf, strlen(buf), ghtml->user_data);
-	}
-	else
 	if (SCM_CONSP(node))
 	{
 		SCM node_list = node;
