@@ -200,6 +200,18 @@ static GttTask * cutted_task = NULL;
 /* ============================================================== */
 /* interval popup actions */
 
+static void
+interval_new_clicked_cb (GtkWidget * w, gpointer data)
+{
+	Wiggy *wig = (Wiggy *) data;
+
+	if (NULL == wig->edit_ivl) wig->edit_ivl = edit_interval_dialog_new();
+
+	wig->interval = gtt_interval_new_insert_after(wig->interval);
+	edit_interval_set_interval (wig->edit_ivl, wig->interval);
+	edit_interval_dialog_show (wig->edit_ivl);
+}
+
 static void
 interval_edit_clicked_cb(GtkWidget * dw, gpointer data) 
 {
@@ -244,7 +256,7 @@ interval_insert_memo_cb(GtkWidget * w, gpointer data)
 	/* try to get billrates consistent across gap */
 	newtask = gtt_interval_get_parent (wig->interval);
 	newtask = gtt_task_dup (newtask);
-	gtt_task_set_memo (newtask, _("New Task"));
+	gtt_task_set_memo (newtask, _("New Diary Entry"));
 	gtt_task_set_notes (newtask, "");
 
 	gtt_interval_split (wig->interval, newtask);
@@ -375,6 +387,20 @@ task_paste_clicked_cb(GtkWidget * w, gpointer data)
 	gtt_task_insert (wig->task, task);
 }
 
+static void
+task_new_interval_cb (GtkWidget * w, gpointer data)
+{
+	Wiggy *wig = (Wiggy *) data;
+
+	if (NULL == wig->edit_ivl) wig->edit_ivl = edit_interval_dialog_new();
+
+	wig->interval = gtt_interval_new();
+	gtt_task_add_interval (wig->task, wig->interval);
+
+	edit_interval_set_interval (wig->edit_ivl, wig->interval);
+	edit_interval_dialog_show (wig->edit_ivl);
+}
+
 static void
 task_popup_cb (Wiggy *wig)
 {
@@ -438,7 +464,8 @@ on_close_clicked_cb (GtkWidget *w, gpointer data)
 	/* close the main journal window ... everything */
 	gtt_project_remove_notifier (wig->prj, redraw, wig);
 	edit_interval_dialog_destroy (wig->edit_ivl);
-	gtk_widget_destroy (wig->top);
+	/* gtk_widget_destroy (wig->top); */
+	gtk_widget_hide (wig->top);
 	gtt_ghtml_destroy (wig->gh);
 	g_free (wig->filepath);
 	g_free (wig);
@@ -471,17 +498,19 @@ html_link_clicked_cb(GtkHTML * html, const gchar * url, gpointer data)
 	if (0 == strncmp (url, "gtt:interval", 12))
 	{
 		wig->interval = addr;
+		wig->task = NULL;
 		if (addr) interval_popup_cb (wig);
 	}
 	else
 	if (0 == strncmp (url, "gtt:task", 8))
 	{
 		wig->task = addr;
+		wig->interval = NULL;
 		if (addr) task_popup_cb (wig);
 	}
 	else
 	{
-		g_warning ("clicked on unknown link duude=%s\n", url);
+		g_warning ("clicked on unknown link %s\n", url);
 	}
 }
 
@@ -564,6 +593,9 @@ do_show_report (const char * report, GttProject *prj)
 	wig->interval_merge_down = glade_xml_get_widget (glxml, "merge_down");
 	wig->interval=NULL;
 
+	glade_xml_signal_connect_data (glxml, "on_new_interval_activate",
+	        GTK_SIGNAL_FUNC (interval_new_clicked_cb), wig);
+	  
 	glade_xml_signal_connect_data (glxml, "on_edit_activate",
 	        GTK_SIGNAL_FUNC (interval_edit_clicked_cb), wig);
 	  
@@ -607,6 +639,9 @@ do_show_report (const char * report, GttProject *prj)
 	glade_xml_signal_connect_data (glxml, "on_paste_activate",
 	        GTK_SIGNAL_FUNC (task_paste_clicked_cb), wig);
 
+	glade_xml_signal_connect_data (glxml, "on_new_interval_activate",
+	        GTK_SIGNAL_FUNC (task_new_interval_cb), wig);
+
 	/* ---------------------------------------------------- */
 	/* finally ... display the actual journal */
 
@@ -629,7 +664,7 @@ static char *
 resolve_path (char *path_frag)
 {
 	const GList *list;
-	char buff[200], *p, *path;
+	char buff[PATH_MAX], *path;
 
 	list = gnome_i18n_get_language_list ("LC_MESSAGES");
 	for ( ; list; list=list->next) 
@@ -639,21 +674,23 @@ resolve_path (char *path_frag)
 		/* See if gtt/ghtml/<lang>/<path_frag> exists */
 		/* look in the local build dir first (for testing) */
 		
-		p = buff;
-		p = stpcpy (p, "ghtml/");
-		p = stpcpy (p, lang);
-		p = stpcpy (p, "/");
-		p = stpcpy (p, path_frag);
+		snprintf (buff, PATH_MAX, "ghtml/%s/%s", lang, path_frag);
 		path = gnome_datadir_file (buff);
 		if (path) return path;
 
-		p = buff;
-		p = stpcpy (p, "gtt/ghtml/");
-		p = stpcpy (p, lang);
-		p = stpcpy (p, "/");
-		p = stpcpy (p, path_frag);
+		snprintf (buff, PATH_MAX, "gtt/ghtml/%s/%s", lang, path_frag);
 		path = gnome_datadir_file (buff);
 		if (path) return path;
+
+		/* some users compile with path settings that gnome
+		 * cannot find.  In that case we have to supply a full
+		 * path and check it's existance directly -- we CANNOT
+		 * use gnome_datadir_file() because it wont work!
+		 *
+		 * -warlord 2001-11-29
+		 */
+		snprintf (buff, PATH_MAX, GTTDATADIR "/ghtml/%s/%s", lang, path_frag);
+		if (g_file_exists (buff)) return g_strdup (buff);
 	}
 	return g_strdup(path_frag);
 }
