@@ -69,7 +69,7 @@ static GnomeUIInfo menu_main_edit[] = {
 		N_("Show the timesheet journal for this project"),
 			       edit_journal,
 			       GNOME_STOCK_MENU_BLANK),
-	GNOMEUIINFO_ITEM_STOCK(N_("New _Task..."),
+	GNOMEUIINFO_ITEM_STOCK(N_("New Diary _Entry"),
 		N_("Change the current task for this project"),
 			       change_task,
 			       GNOME_STOCK_MENU_BLANK),
@@ -157,7 +157,7 @@ static GnomeUIInfo menu_popup[] = {
 		N_("Show the timesheet journal for this project"),
 			       edit_journal,
 			       GNOME_STOCK_MENU_BLANK),
-	GNOMEUIINFO_ITEM_STOCK(N_("New _Task..."),
+	GNOMEUIINFO_ITEM_STOCK(N_("New Diary _Entry"),
 		N_("Change the current task for this project"),
 			       change_task,
 			       GNOME_STOCK_MENU_BLANK),
