@@ -24,6 +24,7 @@
 #include "ctree.h"
 #include "cur-proj.h"
 #include "dialog.h"
+#include "gtt.h"
 #include "idle-timer.h"
 #include "log.h"
 #include "prefs.h"
@@ -83,9 +84,18 @@ timer_func(gpointer data)
 {
 	time_t now = time(0);
 
-	/* even if there is no active prioject,
-	 * we still ahve to zero out the counters periodically. */
-	if (0 == now%60) zero_on_rollover (now);
+	/* Even if there is no active project,
+	 * we still have to zero out the counters periodically. */
+	if (0 == now%60) 
+	{
+	  zero_on_rollover (now);
+
+	  /* Save all accumulated data to file periodically.
+		* This will help ensure against catastrophic data
+		* loss just in case gtt core dumps (which it is doing,
+		* but I cannot reproduce). */
+	  save_all();
+	}
 
 	if (!cur_proj) return 1;
 
@@ -95,7 +105,7 @@ timer_func(gpointer data)
 	{
 		ctree_update_label(global_ptw, cur_proj);
 	} 
-	else if (0 == gtt_project_total_secs_day(cur_proj)) 
+	else if (1 == gtt_project_get_secs_day(cur_proj) % 5) 
 	{
 		ctree_update_label(global_ptw, cur_proj);
 	}
